%MatSpecGUI.m
% (c) Jiri Novak, ESRF, Grenoble, Franc, 2008-
%
% An utility which allow for processing and imaging of 2D x-ray data
% acquired via SPEC software. In particular, the utility is aimed to
% handle x-ray data measured via 1-dimensional detectors (position
% sensitive detectors). MatSpecGUI provide a graphical user interface
% for a convenient access to basic operations with data, including: 
%		 * extracting data from a SPEC file
%    * normalization of measured intensity for beam attenuators and a
%    primary beam monitor
%    * transformation of angular coordinates to Q-space
%    * plotting data
%    * saving plots to image-files
%    * exporting data to ASCII files.
% 

function MSpIntro
global MSpVersion
MSpVersion='091027';

% --- FIGURE -------------------------------------
hnd.MSpIntro = figure(	'Tag', 'MSpIntro', ...
	'Units', 'pixels', ...
	'Position', [520 112 542 720], ...
	'Name', 'MatSpecGUI: Intro', ...
	'MenuBar', 'none', ...
	'NumberTitle', 'off', ...
	'Color', get(0,'DefaultUicontrolBackgroundColor'),...
	'visible','off');

% --- AXES -------------------------------------
hnd.axMSpG = axes(	'Parent', hnd.MSpIntro, ...
	'Tag', 'axMSpG', ...
	'UserData', [], ...
	'Units', 'pixels', ...
	'Position', [76 374 400 252]);

% --- STATIC TEXTS -------------------------------------
hnd.txAuthor = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txAuthor', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [101 637 340 22], ...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',16.667,...
	'FontWeight', 'normal', ...
	'BackgroundColor', [1 1 1], ...
	'String', 'Jiri Novak, ESRF, Grenoble, France, 2008-');

hnd.txTitGNU = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txTitGNU', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [140 332 260 18], ...
	'FontSize', 12, ...
	'FontWeight', 'bold', ...
	'BackgroundColor', [.5 1 1], ...
	'String', 'GNU General Public License');

hnd.txMCond = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txMCond', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [24 90 500 127], ...
	'FontWeight', 'bold', ...
	'BackgroundColor', [1 1 1], ...
	'String', {'License text.'});

hnd.txEmail = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txEmail', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [182 19 180 17], ...
	'ForegroundColor', [0 0 0.5], ...
	'BackgroundColor', [1 1 1], ...
	'String', 'E-mail: novak@physics.muni.cz');

hnd.txMatSpecGUI = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txMatSpecGUI', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [139 670 180 35], ...
	'FontName', 'Times Roman', ...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',26.667,...
	'FontWeight', 'bold', ...
	'BackgroundColor', [.5 1 1], ...
	'String', 'MatSpecGUI ');


hnd.txMSpVersion = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txMSpVersion', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [329 670 80 35], ...
	'FontName', 'Times Roman', ...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',13.667,...
	'FontWeight', 'normal', ...
	'BackgroundColor', [1 1 1], ...
	'String', {'version',MSpVersion});


% --- PUSHBUTTONS -------------------------------------
hnd.pbAccept = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'pbAccept', ...
	'UserData', [], ...
	'Style', 'pushbutton', ...
	'Units', 'pixels', ...
	'Position', [364 52 105 29], ...
	'String', 'Accept',...
	'Callback',{@pbAccept_Callback});

hnd.pbDeny = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'pbDeny', ...
	'UserData', [], ...
	'Style', 'pushbutton', ...
	'Units', 'pixels', ...
	'Position', [85 52 105 29], ...
	'String', 'Deny',...
	'Callback',{@pbDeny_Callback});

% --- EDIT TEXTS -------------------------------------
hnd.txGPL = uicontrol(	'Parent', hnd.MSpIntro, ...
	'Tag', 'txGPL', ...
	'UserData', [], ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [24 227 500 101], ...
	'BackgroundColor', [1 1 1], ...
	'String', {'Edit Text'}, ...
	'Enable', 'inactive', ...
	'Max', 100);

% Save hnd structure
guidata(hnd.MSpIntro,hnd);

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Interventions since here
fid=fopen('GPLicense.txt');
fseek(fid,0,-1);
dat=fread(fid,inf,'uchar=>uchar');
tdat=char(dat');
set(hnd.txGPL,'string',tdat);
fclose(fid);
set(hnd.txGPL,'Enable', 'inactive');
set(hnd.txMSpVersion,'String', {'version',MSpVersion});


set(hnd.txMCond,'String',...	
{		['MatSpecGUI is released WITHOUT ANY WARRANTY and the author ',...
		'can not be held responsible for any problems resulting from ',...
		'any use of this program. ',...
		'It is distributed under the GNU General Public License. ',...
		'Support is provided when there is time available.'],'',...
		['The author would appreciate that any ',...
		'publication to which usage of the program contributed ',...
		'acknowledges the contribution. A reference to the '...
		'program home page '],...
		'http://www.physics.muni.cz/~novak/MatSpecGUI/MatSpecGUI.php',...
		'can be made.'});


mim=imread('MatSpecGUI.png');
imagesc(mim);
set(hnd.axMSpG,'visible','off');
hfig=hnd.MSpIntro;
movegui(hfig,'center');
set(hnd.MSpIntro,'visible','on');
% End of figure function
end


function pbAccept_Callback(hObject,eventdata)
hfig=findobj('tag','MSpIntro');
close(hfig)
MatSpecGUIf
end
function pbDeny_Callback(hObject,eventdata)
hfig=findobj('tag','MSpIntro');
close(hfig)
end


%function MatSpecGUIf
%
%global MSpf MSpScnList MSpScn
%f=figure('Visible','off','Position',[300,300,525,300],...
%	'MenuBar', 'none', ...
%	'Name','MatSpecGUI: Main menu',...
%	'Tag','figGUIMatSpec',...
%	'CloseRequestFcn',{@closeIt});
%
%hLoadFromSpec=uicontrol('Style','pushbutton','String',...
%	'Load from SPEC','Position',[50,250,125,25],...
%	'Callback',{@loadFromSpec_Callback});
%set(hLoadFromSpec, 'TooltipString','Load data from a SPEC file');
%hLoadFromMatFile=uicontrol('Style','pushbutton','String',...
%	'Load from MAT-file','Position',[50,200,125,25],...
%	'Callback',{@loadFromMatFile_Callback});
%hNormalizeIntensities=uicontrol('Style','pushbutton','String',...
%	'Normalize intensities','Position',[50,150,125,25],...
%	'Callback',{@normalizeIntensities_Callback});
%hPlotRoughData=uicontrol('Style','pushbutton','String',...
%	'Plot rough data','Position',[50,100,125,25],...
%	'Callback',{@plotRoughData_Callback});
%
%hTransform2QSpace=uicontrol('Style','pushbutton','String',...
%'Transform to Q-space','Position',[200,250,125,25],...
%'Callback',{@transform2QSpace_Callback});
%hGridData=uicontrol('Style','pushbutton','String','Map to grid',...
%'Position',[200,200,125,25],'Callback',{@griddata_Callback});
%hPlotData=uicontrol('Style','pushbutton','String',...
%	'Plot data','Position',[200,150,125,25],...
%	'Callback',{@plotData_Callback});
%
%hSave2MatFile=uicontrol('Style','pushbutton','String',...
%	'Save to MAT-File','Position',[350,250,125,25],...
%	'Callback',{@save2MatFile_Callback});
%hExport2Ascii=uicontrol('Style','pushbutton','String',...
%'Export to ASCII','Position',[350,200,125,25],'Callback',...
%{@export2Ascii_Callback});
%hAbout=uicontrol('Style','pushbutton','String',...
%	'About','Position',[350,150,125,25],...
%	'Callback',{@about_Callback});
%
%movegui(f,'center');
%set(f,'Visible','on');
%
%
%function loadFromSpec_Callback(source, eventdata)
%	LoadFromSpec;
%end
%
%function loadFromMatFile_Callback(source, eventdata)
%    LoadFromMatFile;
%end
%
%function normalizeIntensities_Callback(source, eventdata)
%	NormalizeIntensities;
%end
%
%function plotRoughData_Callback(source, eventdata)
%    PlotRoughData;
%end
%
%function transform2QSpace_Callback(source, eventdata)
%    Transform2QSpace;
%end
%
%function griddata_Callback(source, eventdata)
%	GridData;
%end
%
%function plotData_Callback(source, eventdata)
%	PlotData;
%end
%
%function save2MatFile_Callback(source, eventdata),
%	SaveToMatFile;
%end
%
%function export2Ascii_Callback(source, eventdata)
%	SaveToASCII;
%end
%
%function about_Callback(source, event),
%	MSpGUIAbout;
%end;
%
%function closeIt(source, eventdata)
%selection = questdlg('Do you want to close the GUI?',...
%'Close Request Function', 'Yes','No','Yes');
%switch selection,
%   case 'Yes',
%      delete(allchild(0));
%      clear global MSpf MSpScnList MSpScn
%   case 'No'
%      return
%end
%end
%
%
%end
function MatSpecGUIf

global MSpf MSpScnList MSpScn MSpVersion
f=figure('Visible','off','Position',[300,300,525,225],...
	'MenuBar', 'none', ...
	'Name','MatSpecGUI: Main menu',...
	'Tag','figGUIMatSpec',...
	'CloseRequestFcn',{@closeIt});

hLoadFromSpec=uicontrol('Style','pushbutton','String',...
	'Load from SPEC',...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Position',[50,175,125,25],...
	'Callback',{@loadFromSpec_Callback});
set(hLoadFromSpec, 'TooltipString',...
'Load data from a SPEC file');
hLoadFromMatFile=uicontrol('Style','pushbutton','String',...
	'Load from MAT-file','Position',[50,125,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@loadFromMatFile_Callback});
hNormalizeIntensities=uicontrol('Style','pushbutton','String',...
	'Normalize intensities','Position',[50,75,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@normalizeIntensities_Callback});
hPlotRoughData=uicontrol('Style','pushbutton','String',...
	'Plot rough data','Position',[50,25,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@plotRoughData_Callback});

hTransform2QSpace=uicontrol('Style','pushbutton','String',...
'Transform to Q-space','Position',[200,175,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
'Callback',{@transform2QSpace_Callback});
hGridData=uicontrol('Style','pushbutton','String','Map to grid',...
'Position',[200,125,125,25],'Callback',{@griddata_Callback});
hPlotData=uicontrol('Style','pushbutton','String',...
	'Plot data','Position',[200,75,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@plotData_Callback});

hSave2MatFile=uicontrol('Style','pushbutton','String',...
	'Save to MAT-File','Position',[350,175,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@save2MatFile_Callback});
hExport2Ascii=uicontrol('Style','pushbutton','String',...
'Export to ASCII','Position',[350,125,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
'Callback',...
{@export2Ascii_Callback});
hAbout=uicontrol('Style','pushbutton','String',...
	'About','Position',[350,75,125,25],...
	'FontName', 'MS Sans Serif ', ...
	'HorizontalAlignment','center',...
	'FontUnits','pixels',...
	'FontSize',10.667,...
	'Callback',{@about_Callback});

movegui(f,'center');
set(f,'Visible','on');


function loadFromSpec_Callback(source, eventdata)
	LoadFromSpec;
end

function loadFromMatFile_Callback(source, eventdata)
    LoadFromMatFile;
end

function normalizeIntensities_Callback(source, eventdata)
	NormalizeIntensities;
end

function plotRoughData_Callback(source, eventdata)
    PlotRoughData;
end

function transform2QSpace_Callback(source, eventdata)
    Transform2QSpace;
end

function griddata_Callback(source, eventdata)
	GridData;
end

function plotData_Callback(source, eventdata)
	PlotData;
end

function save2MatFile_Callback(source, eventdata),
	SaveToMatFile;
end

function export2Ascii_Callback(source, eventdata)
	SaveToASCII;
end

function about_Callback(source, event),
	MSpGUIAbout;
end;

function closeIt(source, eventdata)
selection = questdlg('Do you want to close the GUI?',...
'Close Request Function', 'Yes','No','Yes');
switch selection,
   case 'Yes',
      delete(allchild(0));
      clear global MSpf MSpScnList MSpScn
   case 'No'
      return
end
end


end



