function PlotData
% Plot of reciprocal space map
% MatSpecGUI package
% (c) Jiri Novak, ESRF, Grenoble, France
% Generated on: 21-Oct-2009 14:57:21          

% --- VARIABLES ----------------------------------
global MSpScnList MSpf  MSpScn;
global MSpXDat MSpYDat MSpCDat nameFigPlot fdat
persistent valPopAxis1 valPopAxis2 valPopAxis3
persistent valPopFileFormat 
persistent strLabelAxis1 strLabelAxis2 strLabelAxis3
persistent strMinPlot strMaxPlot
persistent valCheckLogAxis3
persistent valRadioPlotAs
persistent currDir

% Variables initiation
if ~isempty(MSpScnList),
	n=length(MSpScnList );
	for ii = 1:n
			cmd=['global ', MSpScnList{ii}];
			eval(cmd);
	end;
end;

if isempty(valPopAxis1),
	valPopAxis1=1;
end;
if isempty(valPopAxis2),
	valPopAxis2=1;
end;
if isempty(valPopAxis3),
	valPopAxis3=1;
end;
if isempty(valPopFileFormat),
	valPopFileFormat=1;
end;
if isempty(strLabelAxis1),
	strLabelAxis1='Q_y (1/A)';
end;
if isempty(strLabelAxis2),
	strLabelAxis2='Q_z (1/A)';
end;
if isempty(strLabelAxis3),
	strLabelAxis3='log_{10}(Intensity) (Arb. Units)';
end;
if isempty(strMinPlot),
	strMinPlot='0.1';
end;
if isempty(strMaxPlot),
	strMaxPlot='1';
end;
if isempty(valCheckLogAxis3),
	valCheckLogAxis3=1;
end;
if isempty(valRadioPlotAs),
	valRadioPlotAs=[1,0];
end;
if isempty(currDir),
	currDir='./';
end;
PrintFormats={'eps','-depsc2';'ps','-dpsc2';'jpg','-djpeg';...
	'png','-dpng';'pdf','-dpdf'};
nameFigPlot='PlotDataPlot';
defAxFontSize=12;
defTxtFontSize=12;


fig_hdl=findobj('tag','figPlotData');
hndMainGUI=findobj('Tag','figGUIMatSpec');
set(hndMainGUI,'Visible','Off');
if isempty(fig_hdl),
% --- FIGURE -------------------------------------
hnd.figPlotData = figure(	'Tag', 'figPlotData', ...
	'Units', 'pixels', ...
	'Position', [520 336 476 464], ...
	'Name', 'MatSpecGUI: Plot Data', ...
	'MenuBar', 'none', ...
	'NumberTitle', 'off', ...
	'CloseRequestFcn',{@closeIt},...
	'Color', get(0,'DefaultUicontrolBackgroundColor'));

% --- PANELS -------------------------------------
hnd.uipanelAxes = uipanel(	'Parent', hnd.figPlotData, ...
	'Tag', 'uipanelAxes', ...
	'UserData', zeros(1,0), ...
	'Units', 'pixels', ...
	'Position', [11 251 450 138], ...
	'BackgroundColor', [0.5 0.5 0.5], ...
	'Title', 'Axes', ...
	'TitlePosition', 'centertop');

hnd.BtnGroupPlotAs = uibuttongroup(	'Parent', hnd.figPlotData, ...
	'Tag', 'BtnGroupPlotAs', ...
	'UserData', [], ...
	'Units', 'pixels', ...
	'Position', [11 69.9999999999999 423 53], ...
	'BackgroundColor', [0.482 0.482 0.482], ...
	'Title', 'Plot as', ...
	'TitlePosition', 'centertop',...
	'SelectionChangeFcn', @BtnGroupPlotAs_selChangFcn ...
	);

hnd.uipanelLimitsAxis3 = uibuttongroup(	'Parent', hnd.figPlotData, ...
	'Tag', 'uipanelLimitsAxis3', ...
	'UserData', [], ...
	'Units', 'pixels', ...
	'Position', [11 131 274 116], ...
	'BackgroundColor', [0.482 0.482 0.482], ...
	'Title', 'Limits for 3rd axis', ...
	'TitlePosition', 'centertop');

hnd.uipanelSaveToFile = uibuttongroup(	'Parent', hnd.figPlotData, ...
	'Tag', 'uipanelSaveToFile', ...
	'UserData', [], ...
	'Units', 'pixels', ...
	'Position', [11 5.99999999999994 309 46], ...
	'FontWeight', 'bold', ...
	'BackgroundColor', [0.482 0.482 0.482], ...
	'Title', 'Save to file', ...
	'TitlePosition', 'centertop');

% --- STATIC TEXTS -------------------------------------
hnd.txtAxis1 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'txtAxis1', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [9 71 65 22], ...
	'String', '1st axis:', ...
	'HorizontalAlignment', 'left');

hnd.txtAxis2 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'txtAxis2', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [9 43 65 22], ...
	'String', '2nd axis:', ...
	'HorizontalAlignment', 'left');

hnd.txtAxis3 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'txtAxis3', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [9 14 65 22], ...
	'String', '3rd axis:', ...
	'HorizontalAlignment', 'left');

hnd.txtLabels = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'txtLabels', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [275 97 117 22], ...
	'FontWeight', 'bold', ...
	'String', 'Axis label:');

hnd.txtVariables = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'txtVariables', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [94 97 118 22], ...
	'FontWeight', 'bold', ...
	'String', 'Variable:');

hnd.txtTitlePlotData = uicontrol(	'Parent', hnd.figPlotData, ...
	'Tag', 'txtTitlePlotData', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [171 429 117 29], ...
	'FontSize', 14, ...
	'FontWeight', 'bold', ...
	'BackgroundColor', [0.5 0.5 0.5], ...
	'String', 'Plot data');

hnd.txtData = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtData', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [13 41 70 22], ...
	'String', 'Data:', ...
	'HorizontalAlignment', 'left');

hnd.txtPlotLimits = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtPlotLimits', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [13 15.3205128205127 70 22], ...
	'String', 'Plot limits:', ...
	'HorizontalAlignment', 'left');

hnd.txtMin = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtMin', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [93.6666666666667 66.9871794871794 75 22], ...
	'String', 'Min:');

hnd.txtMax = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtMax', ...
	'UserData', zeros(1,0), ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [182 66.9871794871794 75 22], ...
	'String', 'Max:');

hnd.txtMinData = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtMinData', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [94 41 75 22], ...
	'String', '0.1', ...
	'HorizontalAlignment', 'right');

hnd.txtMaxData = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'txtMaxData', ...
	'UserData', zeros(1,0), ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [182 41 75 22], ...
	'String', '1', ...
	'HorizontalAlignment', 'right');

hnd.txtFileFormat = uicontrol(	'Parent', hnd.uipanelSaveToFile, ...
	'Tag', 'txtFileFormat', ...
	'UserData', [], ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [11 7 97 22], ...
	'String', 'File format:', ...
	'HorizontalAlignment', 'left');

hnd.txtDatasetToHandlePlot = uicontrol(	'Parent', hnd.figPlotData, ...
	'Tag', 'txtDatasetToHandlePlot', ...
	'UserData', zeros(1,0), ...
	'Style', 'text', ...
	'Units', 'pixels', ...
	'Position', [11 398 140 23], ...
	'BackgroundColor', [0.5 0.5 0.5], ...
	'String', 'Dataset to be handled:', ...
	'HorizontalAlignment', 'left');

% --- PUSHBUTTONS -------------------------------------
hnd.pushClose = uicontrol(	'Parent', hnd.figPlotData, ...
	'Tag', 'pushClose', ...
	'UserData', [], ...
	'Style', 'pushbutton', ...
	'Units', 'pixels', ...
	'Position', [360 14.9871794871794 70 22], ...
	'FontWeight', 'bold', ...
	'String', 'Close', ...
	'Callback', @pushClose_Callback);

hnd.pushPlot = uicontrol(	'Parent', hnd.BtnGroupPlotAs, ...
	'Tag', 'pushPlot', ...
	'UserData', zeros(1,0), ...
	'Style', 'pushbutton', ...
	'Units', 'pixels', ...
	'Position', [347 8 70 22], ...
	'FontWeight', 'bold', ...
	'String', 'Plot', ...
	'CData', zeros(1,0), ...
	'Callback', @pushPlot_Callback);

hnd.pushSave = uicontrol(	'Parent', hnd.uipanelSaveToFile, ...
	'Tag', 'pushSave', ...
	'UserData', zeros(1,0), ...
	'Style', 'pushbutton', ...
	'Units', 'pixels', ...
	'Position', [227 7 70 22], ...
	'FontWeight', 'bold', ...
	'String', 'Save', ...
	'CData', zeros(1,0), ...
	'Callback', @pushSave_Callback);

% --- RADIO BUTTONS -------------------------------------
hnd.radioContourPlot = uicontrol(	'Parent', hnd.BtnGroupPlotAs, ...
	'Tag', 'radioContourPlot', ...
	'UserData', [], ...
	'Style', 'radiobutton', ...
	'Units', 'pixels', ...
	'Position', [184 8 150 22], ...
	'String', 'Contour plot');
%	'String', 'Contour plot', ...
%	'Callback', @radioContourPlot_Callback);

hnd.radioImage = uicontrol(	'Parent', hnd.BtnGroupPlotAs, ...
	'Tag', 'radioImage', ...
	'UserData', [], ...
	'Style', 'radiobutton', ...
	'Units', 'pixels', ...
	'Position', [17 8 150 22], ...
	'String', 'Image (gridded data)');
%	'String', 'Image (gridded data)', ...
%	'Callback', @radioImage_Callback);

% --- CHECKBOXES -------------------------------------
hnd.checkLogAxis3 = uicontrol(	'Parent', hnd.figPlotData, ...
	'Tag', 'checkLogAxis3', ...
	'UserData', [], ...
	'Style', 'checkbox', ...
	'Units', 'pixels', ...
	'Position', [288 143 139 24], ...
	'BackgroundColor', [0.482 0.482 0.482], ...
	'String', 'Log scale 3rd axis', ...
	'Callback', @checkLogAxis3_Callback);

% --- EDIT TEXTS -------------------------------------
hnd.editLabelAxis1 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'editLabelAxis1', ...
	'UserData', zeros(1,0), ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [236 71 200 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', 'Q_y (1/A)', ...
	'Callback', @editLabelAxis1_Callback, ...
	'CreateFcn', @editLabelAxis1_CreateFcn);

hnd.editLabelAxis2 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'editLabelAxis2', ...
	'UserData', [], ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [236 43 200 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', 'Q_z (1/A)', ...
	'Callback', @editLabelAxis2_Callback, ...
	'CreateFcn', @editLabelAxis2_CreateFcn);

hnd.editLabelAxis3 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'editLabelAxis3', ...
	'UserData', [], ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [236 14 200 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', 'log_10(Intensity) (Arb. Units.)', ...
	'Callback', @editLabelAxis3_Callback, ...
	'CreateFcn', @editLabelAxis3_CreateFcn);

hnd.editPlotMin = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'editPlotMin', ...
	'UserData', [], ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [94 15.3205128205127 75 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', '0.1', ...
	'HorizontalAlignment', 'right', ...
	'Callback', @editPlotMin_Callback, ...
	'CreateFcn', @editPlotMin_CreateFcn);

hnd.editPlotMax = uicontrol(	'Parent', hnd.uipanelLimitsAxis3, ...
	'Tag', 'editPlotMax', ...
	'UserData', [], ...
	'Style', 'edit', ...
	'Units', 'pixels', ...
	'Position', [182 15.3205128205127 75 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', '1', ...
	'HorizontalAlignment', 'right', ...
	'Callback', @editPlotMax_Callback, ...
	'CreateFcn', @editPlotMax_CreateFcn);

% --- POPUP MENU -------------------------------------
hnd.popDatasetToHandlePlot = uicontrol(	'Parent', hnd.figPlotData, ...
	'Tag', 'popDatasetToHandlePlot', ...
	'UserData', [], ...
	'Style', 'popupmenu', ...
	'Units', 'pixels', ...
	'Position', [158 398 140 22], ...
	'String', {'Listbox'}, ...
	'Callback', @popDatasetToHandlePlot_Callback, ...
	'CreateFcn', @popDatasetToHandlePlot_CreateFcn);

hnd.popAxis1 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'popAxis1', ...
	'UserData', [], ...
	'Style', 'popupmenu', ...
	'Units', 'pixels', ...
	'Position', [91 71 133 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', '------', ...
	'Callback', @popAxis1_Callback, ...
	'CreateFcn', @popAxis1_CreateFcn);

hnd.popAxis2 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'popAxis2', ...
	'UserData', [], ...
	'Style', 'popupmenu', ...
	'Units', 'pixels', ...
	'Position', [91 43 134 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', '------', ...
	'Callback', @popAxis2_Callback, ...
	'CreateFcn', @popAxis2_CreateFcn);

hnd.popAxis3 = uicontrol(	'Parent', hnd.uipanelAxes, ...
	'Tag', 'popAxis3', ...
	'UserData', [], ...
	'Style', 'popupmenu', ...
	'Units', 'pixels', ...
	'Position', [91 14 135 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', '------', ...
	'Callback', @popAxis3_Callback, ...
	'CreateFcn', @popAxis3_CreateFcn);

hnd.popFileFormat = uicontrol(	'Parent', hnd.uipanelSaveToFile, ...
	'Tag', 'popFileFormat', ...
	'UserData', zeros(1,0), ...
	'Style', 'popupmenu', ...
	'Units', 'pixels', ...
	'Position', [116 7 92 22], ...
	'BackgroundColor', [1 1 1], ...
	'String', {'eps','ps','pdf','gif','jpeg',''}, ...
	'Callback', @popFileFormat_Callback, ...
	'CreateFcn', @popFileFormat_CreateFcn);
% Changes in a generated file after here

% Save hnd structure
guidata(hnd.figPlotData,hnd);

% Tool timps
set(hnd.txtAxis1,'ToolTipString','Suggested Qx, Qy or Qz');
set(hnd.txtAxis2,'ToolTipString','Suggested Qx, Qy or Qz');
set(hnd.txtAxis3,'ToolTipString',['Suggested PSDNormg, ',...
	'PSDNorm or PSD']);
set(hnd.txtPlotLimits,'ToolTipString',...
	'Suggested: within Min and Max of data');

% Assign function output
fig_hdl = hnd.figPlotData;
% Cahnges from here
% Setting of radio buttons
set(hnd.radioImage,'Min',0,'Max',1,'Value',valRadioPlotAs(1));
set(hnd.radioContourPlot,'Min',0,'Max',1,'Value',valRadioPlotAs(2));
% Setting of check box
set(hnd.checkLogAxis3,'Min',0,'Max',1,'Value',valCheckLogAxis3);
% Scale size to fit the text in
%objFieldnames=fieldnames(hnd);
%for ii=1:length(objFieldnames),
%	curPos=get(hnd.(objFieldnames{ii}),'Position');
%	newPos=curPos*scalingFact;
%	set(hnd.(objFieldnames{ii}),'Position',newPos);
%end;
% Move gui to center, make visible
movegui(fig_hdl,'center');
set(fig_hdl,'visible','on');

else
figure(fig_hdl);
end;

%-------------------------------------------------------------------------------
	function pushClose_Callback(hObject,evendata)
		hndl=findobj('tag',nameFigPlot);
		if ~isempty(hndl),
			close(hndl);
		end;
		hSectFig=findobj('tag','figMapSection');
		if ~isempty(hSectFig),
			close(hSectFig);
		end;
		hfig=findobj('tag',nameFigPlot);
		if ~isempty(hfig),
			close(hfig);
		end;
		set(hndMainGUI,'Visible','On');
		close(fig_hdl);
	end

%-------------------------------------------------------------------------------
	function pushPlot_Callback(hObject,evendata)
		% get global and persistent vars
		MSpScn=getPopCurStr(hnd.popDatasetToHandlePlot);
		strMinPlot=get(hnd.editPlotMin,'String');
		strMaxPlot=get(hnd.editPlotMax,'String');
		
		cmd=['cscn=',MSpScn,';'];
		eval(cmd);
		strAx1Field=getPopCurStr(hnd.popAxis1);
		strAx2Field=getPopCurStr(hnd.popAxis2);
		strAx3Field=getPopCurStr(hnd.popAxis3);
		minPlot=getNumEdit(hnd.editPlotMin);
		maxPlot=getNumEdit(hnd.editPlotMax);
	
		if (valCheckLogAxis3==1),
			if (minPlot<=0 || maxPlot<=0),
			 warndlg(['Axis limits must be >0 for log scaling of 3rd axis.'],...
				'Bad Input','modal');
			 return
			end
			MSpCDat=cscn.(strAx3Field);
			ind=find(MSpCDat<minPlot);
			MSpCDat(ind)=minPlot;
			ind=find(MSpCDat>maxPlot);
			MSpCDat(ind)=maxPlot;
			MSpCDat=log10(MSpCDat);
		else
			MSpCDat=cscn.(strAx3Field);
			ind=find(MSpCDat<minPlot);
			MSpCDat(ind)=minPlot;
			ind=find(MSpCDat>maxPlot);
			MSpCDat(ind)=maxPlot;
		end;

		hfig=findobj('tag',nameFigPlot);
		if isempty(hfig),
			hfig=figure;
			set(hfig,'tag',nameFigPlot,'Name','MatSpecGUI: Plotted data',...
				'PaperUnits', 'normalized',...
				'PaperType', 'A4','PaperPosition', [.09 .29 .65 .42],...
				'DefaultAxesFontUnits', 'points','DefaultAxesFontSize', ...
				defAxFontSize, 'DefaultAxesLineWidth', 1.5,...
				'DefaultAxesPosition',[.16 .15 .73 .73],...
				'DefaultLineLineWidth', 1,...
				'DefaultTextFontUnits', 'points',...
				'DefaultTextFontSize', defTxtFontSize);
		else
			figure(hfig);
		end;
		delete(get(hfig,'children'));
		if (valRadioPlotAs(1)==1),
			imagesc(cscn.(strAx1Field),cscn.(strAx2Field),...
				MSpCDat); axis xy;
		elseif (valRadioPlotAs(2)==1),
			contourf(cscn.(strAx1Field),cscn.(strAx2Field),...
				MSpCDat); 
		end;
		MSpXDat=cscn.(strAx1Field);
		MSpYDat=cscn.(strAx2Field);
		xlabel(strLabelAxis1);
		ylabel(strLabelAxis2);
		hColBar=colorbar;
		set(get(hColBar,'ylabel'),'string',...
			strLabelAxis3,'fontsize',defTxtFontSize);
		% Create button for plotting a section through the RSM
		hMenuSection = uimenu(hfig,'Label','Section');
%		set(hMenuSection,'Callback',@fcnSection);
		hMenuPltSection = uimenu(hMenuSection,'Label','Plot');
		set(hMenuPltSection,'Callback',@fcnPlSection);
		hMenuSvSection = uimenu(hMenuSection,'Label','Save');
		set(hMenuSvSection,'Callback',@fcnSvSection);
	end

%-------------------------------------------------------------------------------
	function pushSave_Callback(hObject,evendata),
		hndl=findobj('tag',nameFigPlot);
		if isempty(hndl),
			warndlg('Data are not yet plotted. Plot first, please.');
			return;
		else
			figure(hndl);
		end;
		fileformat=getPopCurStr(hnd.popFileFormat);
		valPopFileFormat=get(hnd.popFileFormat,'Value');

		[filename,currDir]=uiputfile({['*.',fileformat];['*.*']},'Save As',...
			[currDir,MSpScn,'.',fileformat]);
		if isequal(filename,0) | isequal(currDir,0)
			 errordlg('User selected Cancel','Save As Canceled','Modal')
			 return;
		end
		print(hndl,PrintFormats{valPopFileFormat,2},...
			fullfile(currDir,filename));
	end

	
%-------------------------------------------------------------------------------
	function BtnGroupPlotAs_selChangFcn(hObject,eventdata),
		switch get(eventdata.NewValue,'Tag'),
		case 'radioImage',
			valRadioPlotAs=[1,0];
		case 'radioContourPlot',
			valRadioPlotAs=[0,1];
		end;
	end;

%-------------------------------------------------------------------------------
	function checkLogAxis3_Callback(hObject,evendata)
		valCheckLogAxis3=get(hnd.checkLogAxis3,'Value');
	end

%-------------------------------------------------------------------------------
	function editLabelAxis1_Callback(hObject,evendata)
		strLabelAxis1=get(hnd.editLabelAxis1,'String');
	end

%-------------------------------------------------------------------------------
	function editLabelAxis1_CreateFcn(hObject,evendata)
		set(hObject,'String',strLabelAxis1);
	end

%-------------------------------------------------------------------------------
	function editLabelAxis2_Callback(hObject,evendata)
		strLabelAxis2=get(hnd.editLabelAxis2,'String');
	end

%-------------------------------------------------------------------------------
	function editLabelAxis2_CreateFcn(hObject,evendata)
		set(hObject,'String',strLabelAxis2);
	end

%-------------------------------------------------------------------------------
	function editLabelAxis3_Callback(hObject,evendata)
		strLabelAxis3=get(hnd.editLabelAxis3,'String');
	end

%-------------------------------------------------------------------------------
	function editLabelAxis3_CreateFcn(hObject,evendata)
		set(hObject,'String',strLabelAxis3);
	end

%-------------------------------------------------------------------------------
	function editPlotMin_Callback(hObject,evendata)
		strMinPlot=get(hnd.editPlotMin,'String');
	end

%-------------------------------------------------------------------------------
	function editPlotMin_CreateFcn(hObject,evendata)
		set(hObject,'String',strMinPlot);
	end

%-------------------------------------------------------------------------------
	function editPlotMax_Callback(hObject,evendata)
		strMaxPlot=get(hnd.editPlotMax,'String');
	end

%-------------------------------------------------------------------------------
	function editPlotMax_CreateFcn(hObject,evendata)
		set(hObject,'String',strMaxPlot);
	end

%-------------------------------------------------------------------------------
	function popDatasetToHandlePlot_Callback(hObject,evendata)
		MSpScn=getPopCurStr(hnd.popDatasetToHandlePlot);
		myFieldNames=retrieveDataFields;
		setPopFieldNames(hnd.popAxis1,myFieldNames,valPopAxis1);
		setPopFieldNames(hnd.popAxis2,myFieldNames,valPopAxis2);
		setPopFieldNames(hnd.popAxis3,myFieldNames,valPopAxis3);
		cMax=getDataExtreme(1);
		if ~isempty(cMax),
			set(hnd.txtMaxData,'String',num2str(cMax,'%8.2e'));
		else
			set(hnd.txtMaxData,'String','1');
		end;
		cMin=getDataExtreme(0);
		if ~isempty(cMin),
			set(hnd.txtMinData,'String',num2str(cMin,'%8.2e'));
		else
			set(hnd.txtMinData,'String','0.1');
		end;
	end

%-------------------------------------------------------------------------------
	function popDatasetToHandlePlot_CreateFcn(hObject,evendata)
		if (~isempty(MSpScn) && ~isempty(MSpScnList)),
				ii=find(strcmp(MSpScn,MSpScnList),1);
				set(hObject,'String',MSpScnList,'Value', ii);
		elseif length(MSpScnList)>0,
				set(hObject,'String',MSpScnList,'Value', 1);
		else
				set(hObject,'String',{'------'});
		end;
	end

%-------------------------------------------------------------------------------
	function popAxis1_Callback(hObject,evendata)
		valPopAxis1=get(hnd.popAxis1,'Value');
	end
%-------------------------------------------------------------------------------
	function popAxis1_ButtonDownFcn(hObject,evendata),
		valPopAxis1=get(hnd.popAxis1,'Value');
	end;

%-------------------------------------------------------------------------------
	function popAxis1_CreateFcn(hObject,evendata)
		myFieldNames=retrieveDataFields;
		valPopAxis1=setPopFieldNames(hObject,myFieldNames,valPopAxis1);
	end

%-------------------------------------------------------------------------------
	function popAxis2_Callback(hObject,evendata)
		valPopAxis2=get(hnd.popAxis2,'Value');
	end

%-------------------------------------------------------------------------------
	function popAxis2_CreateFcn(hObject,evendata)
		myFieldNames=retrieveDataFields;
		valPopAxis2=setPopFieldNames(hObject,myFieldNames,valPopAxis2);
	end

%-------------------------------------------------------------------------------
	function popAxis3_Callback(hObject,evendata)
		valPopAxis3=get(hnd.popAxis3,'Value');
		cMax=getDataExtreme(1);
		if ~isempty(cMax),
			set(hnd.txtMaxData,'String',num2str(cMax,'%8.2e'));
		else
			set(hnd.txtMaxData,'String','1');
		end;
		cMin=getDataExtreme(0);
		if ~isempty(cMin),
			set(hnd.txtMinData,'String',num2str(cMin,'%8.2e'));
		else
			set(hnd.txtMinData,'String','0.1');
		end;
	end

%-------------------------------------------------------------------------------
	function popAxis3_CreateFcn(hObject,evendata)
		myFieldNames=retrieveDataFields;
		valPopAxis3=setPopFieldNames(hObject,myFieldNames,valPopAxis3);
	end

%-------------------------------------------------------------------------------
	function popFileFormat_Callback(hObject,evendata)
		valPopFileFormat=get(hnd.popFileFormat,'Value');
	end

%-------------------------------------------------------------------------------
	function popFileFormat_CreateFcn(hObject,evendata)
		set(hObject,'String',PrintFormats(:,1));
		valPopFileFormat=setPopFieldNames(hObject,PrintFormats(:,1),...
			valPopFileFormat);
	end

%-------------------------------------------------------------------------------
	function txtMaxData_CreateFcn(hObject,evendata),
		cMax=getDataExtreme(1);
		if ~isempty(cMax),
			set(hObject,'String',num2str(cMax,'%8.2e'));
		else
			set(hObject,'String','1');
		end;
	end;
%-------------------------------------------------------------------------------
	function txtMinData_CreateFcn(hObject,evendata),
		cMin=getDataExtreme(0);
		if ~isempty(cMin),
			set(hObject,'String',num2str(cMin,'%8.2e'));
		else
			set(hObject,'String','0.1');
		end;
	end;
%-------------------------------------------------------------------------------
function closeIt(gcbf,ar2);
hFigPlot=findobj('tag',nameFigPlot);
if ~isempty(hFigPlot),
	close(hFigPlot);
end;
hSectFig=findobj('tag','figMapSection');
if ~isempty(hSectFig),
	close(hSectFig);
end;
set(hndMainGUI,'Visible','On');
delete(fig_hdl);
end;
%-------------------------------------------------------------------------------
	function res=getDataExtreme(flgMinMax),
		% returns minima or maxima of current data on 3rd axis
		% flgMinMax=0 ... minima
		% flgMinMax=1 ... maxima
		cDataset=getPopCurStr(hnd.popDatasetToHandlePlot);
		cAxis3=getPopCurStr(hnd.popAxis3);
		MSpCDat=0;
		res=[];

		if exist(cDataset),
			myFieldNames=retrieveDataFields;
			if any(strcmp(cAxis3,myFieldNames)),
				cmd=['MSpCDat=',cDataset,'.',cAxis3,';'];
				eval(cmd);
				if isnumeric(MSpCDat),
					if flgMinMax==1,
						res=max(max(MSpCDat));
					else
						res=min(min(MSpCDat));
					end;
				end;
			end;
		end;
	end;




	function myFieldNames=retrieveDataFields;
		% retrieve fields of the dataset
		myFieldNames={};
		flgIsStruct=0;
		if ~isempty(MSpScn),
				if  iscell(MSpScn),
						MSpScn=MSpScn{1};
				end;
				cmd=['flgIsStruct=isstruct(', MSpScn,');'];
				eval(cmd);
				if flgIsStruct,
						cmd=['myFieldNames=fieldnames(',MSpScn,');'];
						eval(cmd);
				else
						myFieldNames={};
				end;
		else,
				myFieldNames={};
		end;
	end;

	function str=getPopCurStr(hndl),
		strs=get(hndl,'String');
		ii=get(hndl,'Value');
		str=strs{ii};
	end;
	function val1=setPopFieldNames( hndl, str, val),
		% Set popup menu field names and the current filed (val)
		% hndl ... handle to the popup menu
		% str ... string
		% val ... value
		if (isempty(str)),
			lstr=1;
			str={'------'};
		else if (iscell(str)),
			lstr=length(str);
		else
			lstr=1;
		end;
		end;

		if (val>lstr),
			val=1;
		end;
		
		set(hndl,'String',str);
		set(hndl,'Value',val);
		val1=val;
	end;
%	function fcnSection(hObject,evendata),
	function fcnPlSection(hObject,evendata),
	% Function run after pressing butto section in the map figure
		[mx,my]=ginput(2);
		fprintf(1,'MatSpecGUI, section end points:\n');
		fprintf(1,'x1=[%g,%g]\n',mx(1),my(1));
		fprintf(1,'x2=[%g,%g]\n',mx(2),my(2));
		nx=length(MSpXDat);
		ny=length(MSpYDat);
		limxim=[min(MSpXDat) max(MSpXDat)];
		limyim=[min(MSpYDat) max(MSpYDat)];
		npx=abs(diff(mx))/(limxim(2)-limxim(1))*nx;
		npy=abs(diff(my))/(limyim(2)-limyim(1))*ny;
		np=round(sqrt(npx^2+npy^2));
		xi=linspace(mx(1),mx(2),np);
		yi=linspace(my(1),my(2),np);
		MSpZSec=interp2(MSpXDat,MSpYDat',MSpCDat,xi,yi);
		while 1,
			ansX=inputdlg(['Plot as function: axis x, axis y, '...
				'abs(x^2+y^2)?= x, y, xy'], 'Plot section');
			switch char(ansX)
			case 'x'
				MSpXSec=xi;
				break;
			case 'y'
				MSpXSec=yi;
				break;
			case 'xy'
				MSpXSec=sqrt(xi.^2+yi.^2);
				break;
			end;
		end;
		hSectFig=findobj('tag','figMapSection');
		if isempty(hSectFig),
			hSectFig=figure;
			set(hSectFig,'tag','figMapSection');
		else
			figure(hSectFig);
		end;
		plot(MSpXSec,MSpZSec,'x');
		ylabel('Intenisty (Arb. Units.)');
		fdat.x=xi;
		fdat.y=yi;
		fdat.z=MSpZSec;
		set(hSectFig,'UserData',fdat);
		set(hSectFig,'Name','MatSpecGUI: Section through RSM');
	end;
	function fcnSvSection(hObject,evendata),
		hSectFig=findobj('tag','figMapSection');
		if isempty(hSectFig),
			warndlg('No Section plotted','Warning','modal');
			return;
		end;
		[filename,currDir]=uiputfile({['*.*']},'Save As',...
			[currDir,MSpScn,'_section.dat']);
		out=[fdat.x;fdat.y;fdat.z]';
		save(fullfile(currDir,filename),'out','-ascii');
	end;

	function num=getNumEdit(hndl),
		mstr=get(hndl,'String');
		num=str2double(mstr);
		if isnan(num)
		 errordlg([mstr, ' is not a numeric value.'],...
		 	'Bad Input','modal');
		 return
		end
	end;
end
